aboutsummaryrefslogtreecommitdiff
path: root/engines/mohawk/riven_stacks/pspit.cpp
diff options
context:
space:
mode:
authorBastien Bouclet2017-07-02 06:15:15 +0200
committerEugene Sandulenko2017-07-03 08:50:10 +0200
commitb552719a81faa8992e53a0fde1098747d89d40d4 (patch)
treef46ea1c065aa4be5d8c1acf6832f9dfa9d4da6e8 /engines/mohawk/riven_stacks/pspit.cpp
parent95951eebf7cf677cee7ef044590754f5971c2b15 (diff)
downloadscummvm-rg350-b552719a81faa8992e53a0fde1098747d89d40d4.tar.gz
scummvm-rg350-b552719a81faa8992e53a0fde1098747d89d40d4.tar.bz2
scummvm-rg350-b552719a81faa8992e53a0fde1098747d89d40d4.zip
MOHAWK: Switch external command arguments to Common::Array
Diffstat (limited to 'engines/mohawk/riven_stacks/pspit.cpp')
-rw-r--r--engines/mohawk/riven_stacks/pspit.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/engines/mohawk/riven_stacks/pspit.cpp b/engines/mohawk/riven_stacks/pspit.cpp
index 07a91f2cff..a3134754b4 100644
--- a/engines/mohawk/riven_stacks/pspit.cpp
+++ b/engines/mohawk/riven_stacks/pspit.cpp
@@ -80,9 +80,9 @@ void PSpit::catherineIdleTimer() {
installTimer(TIMER(PSpit, catherineIdleTimer), timeUntilNextMovie);
}
-void PSpit::xpisland990_elevcombo(uint16 argc, uint16 *argv) {
- // Play button sound based on argv[0]
- _vm->_sound->playSound(argv[0] + 5);
+void PSpit::xpisland990_elevcombo(const ArgumentArray &args) {
+ // Play button sound based on args[0]
+ _vm->_sound->playSound(args[0] + 5);
_vm->delay(500);
// It is impossible to get here if Gehn is not trapped. However,
@@ -95,33 +95,33 @@ void PSpit::xpisland990_elevcombo(uint16 argc, uint16 *argv) {
// pelevcombo keeps count of how many buttons we have pressed in the correct order.
// When pelevcombo is 5, clicking the handle will show the video freeing Catherine.
- if (correctDigits < 5 && argv[0] == getComboDigit(_vm->_vars["pcorrectorder"], correctDigits))
+ if (correctDigits < 5 && args[0] == getComboDigit(_vm->_vars["pcorrectorder"], correctDigits))
correctDigits++;
else
correctDigits = 0;
}
-void PSpit::xpscpbtn(uint16 argc, uint16 *argv) {
+void PSpit::xpscpbtn(const ArgumentArray &args) {
runDomeButtonMovie();
}
-void PSpit::xpisland290_domecheck(uint16 argc, uint16 *argv) {
+void PSpit::xpisland290_domecheck(const ArgumentArray &args) {
runDomeCheck();
}
-void PSpit::xpisland25_opencard(uint16 argc, uint16 *argv) {
+void PSpit::xpisland25_opencard(const ArgumentArray &args) {
checkDomeSliders();
}
-void PSpit::xpisland25_resetsliders(uint16 argc, uint16 *argv) {
+void PSpit::xpisland25_resetsliders(const ArgumentArray &args) {
resetDomeSliders(14);
}
-void PSpit::xpisland25_slidermd(uint16 argc, uint16 *argv) {
+void PSpit::xpisland25_slidermd(const ArgumentArray &args) {
dragDomeSlider(14);
}
-void PSpit::xpisland25_slidermw(uint16 argc, uint16 *argv) {
+void PSpit::xpisland25_slidermw(const ArgumentArray &args) {
checkSliderCursorChange(14);
}